# TabContainer CSS Glitch Tests

Collected tests for problems with missing borders for TabContainer, in particular problems with the border between the tab buttons and the tab content.

## Borders in TooltipDialog

Open TooltipDialog and make sure the horizontal border between tab buttons and content don't extend past the edge of the TabContainer. Also check that button for second tab (unselected tab) is visible on IE6.

Show Tooltip Dialog with TabContainer

This is the first tab.

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

This is the second tab.

ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

## Initial missing border

Make sure the TabContainers below show the border between tab buttons and tab content. Previously it didn't show on initial page load, but showed after resize.

## Missing border on zoom

Make sure separating border doesn't disappear on zoom (not text-size increase/decrease but zoom). Problem used to occur on FF/windows and IE8.

Once upon a time there was a dear little girl who was loved by every one who looked at her, but most of all by her grandmother, and there was nothing that she would not have given to the child.
Some content here.
Yet more content.